@@ -27,11 +27,15 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 	TrunkGroup *grp = NULL;
 	char *sp;
 	int ctrl;
+	unsigned chk;
+	char **argv;
+	Request *req;
 
 	switch(event->id)
 	{
 	case TRUNK_ENTER_STATE:
 		debug->DebugState(this, "idle");
+		ScriptSymbol::Purge();
 		setCPADetect(CPA_DIALTONE, false);
 		setCPADetect(CPA_BUSYTONE, false);
 		flags.dsp = DSP_MODE_INACTIVE;
@@ -72,6 +76,13 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 #endif
 #endif
 		}
+		value = group->chkRequest();
+		chk = atoi(value);
+		if(!chk && stricmp(value, "hangup"))
+			return true;
+		if(chk < group->getReady())
+			chk = group->getReady();
+		setTimer(chk);
 		return true;
 	case TRUNK_LINE_WINK:
 	case TRUNK_CPA_DIALTONE:
@@ -79,8 +90,31 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 	case TRUNK_STOP_DISCONNECT:
 		return true;
 	case TRUNK_MAKE_BUSY:
+		endTimer();
 		handler = &PhonedevTrunk::busyHandler;
 		return true;
+	case TRUNK_TIMER_EXPIRED:
+		req = group->getRequest();
+		if(req)
+		{
+			argv = req->getList();
+			start = *(argv++);
+			if(Attach(start))
+			{
+				flags.trunk = TRUNK_MODE_OUTGOING;
+				setList(argv);
+				endTimer();
+				handler = &PhonedevTrunk::seizeHandler;
+				group->incOutgoing();
+				delete req;
+				return true;
+			}
+			delete req;
+		}
+		chk = atoi(group->chkRequest());
+		if(chk)
+			setTimer(chk);
+		return true;		
 	case TRUNK_START_SCRIPT:
 		flags.trunk = TRUNK_MODE_OUTGOING;
 	case TRUNK_RING_START:
@@ -106,7 +140,8 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 				value = strtok_r(NULL, "=", &sp);
 				if(data && value)
 					setConstant(data, value);
-			}		
+			}
+			endTimer();		
 			if(flags.trunk == TRUNK_MODE_OUTGOING)
 			{
 				handler = &PhonedevTrunk::seizeHandler;
@@ -126,6 +161,7 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 		rings = 1;
 		flags.trunk = TRUNK_MODE_INCOMING;
 		group->incIncoming();
+		endTimer();
 		handler = &PhonedevTrunk::ringHandler;
 		return true;
 	}
