@@ -444,20 +444,11 @@ void PhonedevTrunk::getEvents(void)
 			strncpy(buf, cid.ixjcid.number, cid.ixjcid.numlen);
 			buf[cid.ixjcid.numlen] = 0;
 			if(cid.ixjcid.numlen)
-			{
-				setSymbol(SYM_CALLERTYPE, 4);
-				setSymbol(SYM_CALLERTYPE, "cid");
-				setSymbol(SYM_CALLER, 11);
 				setSymbol(SYM_CALLER, buf);
-				setConstant("cid", buf);
-			}
 			strncpy(buf, cid.ixjcid.name, cid.ixjcid.namelen);
 			buf[cid.ixjcid.namelen] = 0;
 			if(cid.ixjcid.namelen)
-			{
-				setSymbol(SYM_CALLERNAME, 80);
-				setSymbol(SYM_CALLERNAME, buf);
-			}
+				setSymbol(SYM_NAME, buf);
 			if(cid.ixjcid.numlen)
 				flags.dsp = DSP_MODE_INACTIVE;
 			break;
