@@ -69,9 +69,6 @@ bool PikaTrunk::answerHandler(TrunkEvent *event)
 		status[id] = 'r';
 		debug->DebugState(this, "answer");
 	case TRUNK_RINGING_OFF:
-		if(rings > 1)
-			stopDSP();
-
 		if(data.answer.rings > rings)
 		{
 			setTimer(data.answer.timeout);
