@@ -59,62 +59,50 @@ bool PikaTrunk::dialHandler(TrunkEvent *event)
 	case TRUNK_ENTER_STATE:
 		debug->DebugState(this, "dial");
 		endTimer();
-		getVPResource();
+		if(!getVPResource())
+		{
+			setSymbol(SYM_ERROR, "dsp-unavailable");
+			TrunkSignal(TRUNK_SIGNAL_ERROR);
+			handler = &PikaTrunk::stepHandler;
+			return true;
+		}
 		setDTMFDetect(false);
 
-// Matt B
-
 		if(!flags.offhook)
 		{
-		    // Take the line offhook
-		    rtn = PK_TRUNK_OffHook(hTrk);
-		  
-		    if(rtn != PK_TRUNK_E_NOT_ONHOOK)
-		    {
-		        flags.offhook = true;
-		    }
-		    else
-		    {
-		        return false;
-		    }
+			rtn = PK_TRUNK_OffHook(hTrk);
+			if(rtn != PK_TRUNK_E_NOT_ONHOOK)
+		        	flags.offhook = true;
+		    	else
+		        	return false;
 		}
-// Matt B
-	
        		return true;
 
-	// Matt B
-
 	case TRUNK_OFF_HOOK:
-
-	       while(*data.dialxfer.digit == 'F' || *data.dialxfer.digit == 'W')
+		while(*data.dialxfer.digit == 'F' || *data.dialxfer.digit == 'W')
 			++data.dialxfer.digit;
 
 		rtn = PK_VP_PlayDTMFString(hDsp, data.dialxfer.digit);
 
-		if(rtn == PK_DRV_E_RESOURCE_BUSY)
+		switch(rtn)
 		{
-		    printf("\ndial error: PK_DRV_E_RESOURCE_BUSY\n");
+		default:
+			return true;
+		case PK_DRV_E_RESOURCE_BUSY:
+			setSymbol(SYM_ERROR, "dsp-busy");
+			break;
+		case PK_DRV_E_INVALID_RESOURCE:
+			setSymbol(SYM_ERROR, "dsp-invalid");
+			break;
+		case PK_DRV_E_RESOURCE_NOT_AVAIL:
+			setSymbol(SYM_ERROR, "dsp-unavailable");
 		}
-
-		if(rtn == PK_DRV_E_INVALID_RESOURCE)
-		{
-		    printf("\ndial error: PK_DRV_E_INVALID_RESOURCE (invalid dsp handle)\n");
-		}
-
-		if(rtn == PK_DRV_E_RESOURCE_NOT_AVAIL)
-		{
-		      printf("\ndial error: PK_DRV_E_RESOURCE_NOT_AVAIL ?\n");
-		}    
-
-		printf("\n dial return: %d\n", rtn);
-
+		TrunkSignal(TRUNK_SIGNAL_ERROR);
+		handler = &PikaTrunk::stepHandler;
 	        return true;
 
 	case TRUNK_LINE_WINK:
 	        return true;
-
-	// Matt B
-
 	}
 
 	return false;
