@@ -20,7 +20,8 @@ bool VPBTrunk::ringHandler(TrunkEvent *event)
 {
 	char script[256];
 	int argc = 0;
-	const char *start = NULL;
+	char *args[2];
+	char **start = NULL;
 	const char *data;
 	const char *value;
 	TrunkGroup *grp = NULL;
@@ -52,9 +53,10 @@ bool VPBTrunk::ringHandler(TrunkEvent *event)
 		sprintf(script, "ring%d", event->parm.ring.digit);
 		if(!grp)
 			grp = group;
-		start = group->getSchedule(script);
-		if(Attach(start))
+		start = getInitial(args);
+		if(Attach(*start))
 		{
+			setList(++start);
 			handler = &VPBTrunk::stepHandler;
 			return true;
 		}
