@@ -55,6 +55,7 @@ typedef	short	tpport_t;
 class Trunk;
 class Service;
 class phTone;
+class TrunkGroup;
 
 typedef enum {
 	MODULE_DELIVERY,
@@ -186,6 +187,7 @@ typedef enum {
 	TRUNK_CPA_NORINGBACK,
 	TRUNK_CPA_NOANSWER,
 	TRUNK_CPA_CONNECT,
+	TRUNK_DSP_READY,	// dsp resource became available
 
 	// driver specific events and anomolies
 
@@ -345,6 +347,7 @@ typedef struct
 		timeout_t duration;
 		trunkstep_t step;
 		char align[8];
+		dspmode_t dsp;
 	} parm;
 } TrunkEvent;
 
@@ -851,6 +854,14 @@ public:
 	inline int priScheduler(void)
 		{return atoi(getLast("scheduler"));};
 
+	/**
+	 * Get the relative priority to run gui at.
+	 *
+	 * @return gui priority (relative).
+	 */
+	inline int priGUI(void)
+		{return atoi(getLast("gui"));};
+
 	/**
 	 * Get number of milliseconds to delay each script step.
 	 *
@@ -1007,6 +1018,43 @@ private:
 	Auditdata();
 };
 
+/**
+ * Requests are used to queue service requests to a trunk group.  These
+ * are usually for scripts that will perform some form of outbound
+ * dialing.  Requests are queued until either they can be serviced, or
+ * they are expired.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short Request service.
+ */
+class Request
+{
+private:
+	friend class TrunkGroup;
+
+	static unsigned seq;
+
+	unsigned id;
+	Request *next;
+	time_t expires;
+	TrunkGroup *group;
+
+	char *argv[33];
+	char buffer[512];
+
+	void Detach(void);
+	
+public:
+	Request(TrunkGroup *grp, const char *text, unsigned expire);
+	~Request()
+		{Detach();};
+
+	inline char **getList(void)
+		{return argv;};
+
+	bool isExpired(void);
+};
+
 /**
  * Trunk "groups" provide keydata configuration information that apply
  * to a group of trunk ports represented under a common "group" identity.
@@ -1023,9 +1071,12 @@ private:
 	friend class KeyServer;
 	friend class Scheduler;
 	friend class Audit;
+	friend class TestDebug;
+	friend class Request;
 	static TrunkGroup *first;
 	TrunkGroup *next;
 	char schedule[65];
+	Request *reqfirst, *reqlast;
 
 	void setSchedule(const char *str);
 
@@ -1050,15 +1101,48 @@ public:
 	 *
 	 * @return number of rings to answer.
 	 */
-	inline int getAnswer(void)
+	inline unsigned getAnswer(void)
 		{return atoi(getLast("answer"));};
 
+	/**
+	 * Get the number of milliseconds for active caller id.
+	 *
+	 * @return number of milliseconds of caller id.
+	 */
+	inline unsigned getCallerid(void)
+		{return atoi(getLast("callerid"));};
+
+	/**
+	 * Get pickup gaurd time for this trunk group.
+	 *
+	 * @return number of milliseconds for call pickup.
+	 */
+	inline unsigned getPickup(void)
+		{return atoi(getLast("pickup"));};
+
+	/**
+	 * Get handling for trunk group "pending requests".
+	 *
+	 * @return symbol or timer value.
+	 */
+	inline const char *chkRequest(void)
+		{return getLast("requests");};
+
+	/**
+	 * Get ready timer for trunk before handling requests when
+	 * idle.
+	 *
+	 * @return ready timer in milliseconds.
+	 */
+	inline timeout_t getReady(void)
+		{return atol(getLast("ready"));};
+	
 	/**
 	 * Get the time delay of each ring.
 	 *
 	 * @return ring time between rings.
 	 */
-	inline int getRingTime(void)
+	inline unsigned getRingTime(void)
 		{return atoi(getLast("ringtime"));};
 
 	/**
@@ -1093,6 +1177,14 @@ public:
 	inline timeout_t getDialspeed(void)
 		{return atol(getLast("dialspeed"));};
 
+	/**
+	 * Get the telephone number associated with this trunk group
+	 * if one is associated with it.
+	 *
+	 * @return telephone number if known.
+	 */
+	const char *getNumber(void);
+
 	/**
 	 * Get the name of the script to "schedule" for this group.
 	 *
@@ -1106,6 +1198,20 @@ public:
 	 */
 	inline void incCapacity(void)
 		{++capacity;};
+
+	/**
+	 * Get the next active request pending for this group.
+	 *
+	 * @return next request queued or NULL.
+	 */
+	Request *getRequest(void);
+
+	/**
+	 * Find a named trunk group.
+	 *
+	 * @return trunk group object if found.
+	 */
+	friend TrunkGroup *getGroup(const char *name);
 };
 
 /**
@@ -1236,6 +1342,11 @@ public:
 	 */
 	void loadFunctions(void);
 
+	/**
+	 * Attempt to load Map files into the server.
+	 */
+	void loadMaps(void);
+
 	/**
 	 * Attempt to load DSO based protocol modules into the server.
 	 */
@@ -1373,6 +1484,7 @@ public:
 class Trunk : public ScriptInterp
 {
 private:
+	friend class TestDebug;
 	friend class aaScript;
 	friend class Translator;
 	friend class ScriptInterface;
@@ -1384,6 +1496,7 @@ private:
 	int cdrc;
 	numbersymbol_t numbers[5];
 
+	bool scrRequest(void);
 	bool scrLibonce(void);
 	bool scrLibexec(void);
 	bool scrHangup(void);
@@ -1406,6 +1519,7 @@ private:
 	bool scrDial(void);
 	bool scrTransfer(void);
 	bool scrSpeak(void);
+	bool scrMap(void);
 	bool scrLookup(void);
 	bool scrUpdate(void);
 	bool scrDeliver(void);
@@ -1580,6 +1694,22 @@ protected:
 	 */
 	unsigned long getMask(void);
 
+	/**
+	 * We get the scheduled or dnis or callerid map table values.
+	 *
+	 * @return argument list for startup.
+	 * @param buffer for defaults.
+	 */
+	char **getInitial(char **args);
+
+	/**
+	 * Set a list of keyword values into the variable space of the
+	 * script interpreter.
+	 *
+	 * @param list of keyword pairs.
+	 */
+	void setList(char **list);
+
 	Trunk(int port);
 public:
 	/**
@@ -1724,11 +1854,13 @@ protected:
 	bool putSymbol(char **argv);
 	bool submit(char **argv);
 	bool login(char **argv);
-	bool startScript(int id, char **argv);
-	bool ringScript(int id, char **argv);
+	bool mapFiles(char **argv);
+	bool startScript(char **argv);
+	bool ringScript(char **argv);
 	bool busyLine(char **argv);
 	bool idleLine(char **argv);
 	bool hangupLine(char **argv);
+	bool reqScript(char **argv);
 
 public:
 	/**
@@ -1888,6 +2020,15 @@ public:
 	 */
 	virtual int getTrunkCount(void) = 0;
 
+	/**
+	 * Get active number of ports actually deployed by the current
+	 * driver.
+	 *
+	 * @return actual trunks used.
+	 */
+	virtual int getTrunkUsed(void) 
+		{return getTrunkCount();};
+
 	/**
 	 * Get the trunk group of an identified port.
 	 * 
@@ -2367,6 +2508,48 @@ public:
 	friend AudioFeed *getAudioFeed(const char *name);
 };
 
+/**
+ * Maps are used to load translation tables for call routing and selection
+ * based on digits set.  Map tables are loaded into and may be refereshed
+ * in memory from text files.
+ *
+ * @short map digit translation tables.
+ * @author David Sugar <dyfet@ostel.com>
+ */
+class Map : private MemPager
+{
+private:
+	static ThreadLock lock;
+	static Map *first, *last;
+
+	typedef struct _sym
+	{
+		struct _sym *next;
+		char *key;
+		char **values;
+	}	mapsym_t;
+
+	typedef struct
+	{
+		mapsym_t *keys[127];
+	} mapkey_t;
+
+	mapkey_t *digits[32];
+
+	Map *next, *prev;
+	char *name;
+
+	unsigned getKey(const char *key, unsigned len = 0);
+	char **getList(const char *key, unsigned len);
+	~Map();
+
+public:
+	Map(const char *path, const char *name);
+
+	friend char **getMap(const char *map, const char *key);
+	friend void endMaps(void);
+};
+
 /**
  * Protocols are used for processing transactional requests such as
  * those performed thru modules, but thru a TCP protocol.  These support
