@@ -56,9 +56,11 @@ ScriptCommand("/bayonne/script")
 		{"dial", (scriptmethod_t)&Trunk::scrDial, &ScriptCommand::chkHasArgs},
 		{"transfer", (scriptmethod_t)&Trunk::scrTransfer, &ScriptCommand::chkHasArgs},
 		{"pause", (scriptmethod_t)&Trunk::scrPause, &ScriptCommand::chkHasArgs},
+		{"request", (scriptmethod_t)&Trunk::scrRequest, &ScriptCommand::chkHasArgs},
 		{"libexec", (scriptmethod_t)&Trunk::scrLibexec, &ScriptCommand::chkHasArgs},
 		{"libonce", (scriptmethod_t)&Trunk::scrLibonce, &ScriptCommand::chkHasArgs},
 		{"speak", (scriptmethod_t)&Trunk::scrSpeak, &ScriptCommand::chkHasArgs},
+		{"map", (scriptmethod_t)&Trunk::scrMap, &ScriptCommand::chkHasArgs},
 		{"lookup", (scriptmethod_t)&Trunk::scrLookup, &ScriptCommand::chkHasArgs},
 		{"update", (scriptmethod_t)&Trunk::scrUpdate, &ScriptCommand::chkHasArgs},
 		{"deliver", (scriptmethod_t)&Trunk::scrDeliver, &ScriptCommand::chkHasArgs},
