@@ -486,6 +486,31 @@ void Plugins::loadAuditing(void)
 	}
 }
 
+void Plugins::loadMaps(void)
+{
+	char path[256];
+	char list[512];
+	char *cp = (char *)getLast("maps");
+
+	if(!cp)
+		return;
+
+	strcpy(list, cp);
+	cp = strtok(list, " \t\n;,");
+	while(cp)
+	{
+		if(!*cp)
+			break;
+
+		strcpy(path, "maps/");
+		strcat(path, cp);
+		strcat(path, ".map");
+		if(canAccess(path))
+			new Map(path, cp);
+		cp = strtok(NULL, " \t\n;,");
+	}
+}
+
 void Plugins::loadFunctions(void)
 {
 	char path[256];
@@ -737,6 +762,10 @@ Keydata("/bayonne/trunks"), CallStat()
 		{"dialtone", "800"},
 		{"dialspeed", "160"},
 		{"volume", "80"},
+		{"callerid", "1500"},
+		{"pickup", "500"},
+		{"requests", "hangup"},
+		{"ready", "1000"},
 		{NULL, NULL}};
 
 	int count = driver->getTrunkCount();
@@ -778,6 +807,7 @@ Keydata("/bayonne/trunks"), CallStat()
 
 	Load(keys);
 	next = NULL;
+	reqfirst = reqlast = NULL;
 
 	if(first)
 		first->next = this;
@@ -785,6 +815,29 @@ Keydata("/bayonne/trunks"), CallStat()
 		first = this;
 }	
 
+Request *TrunkGroup::getRequest(void)
+{
+	Request *req = NULL;
+
+	EnterMutex();
+	while(reqfirst)
+	{
+		if(reqfirst->isExpired())
+		{
+			slog(SLOG_WARNING) << "request: " << getName() << "(" << reqfirst->id << ") expired...";
+			delete reqfirst;
+			continue;
+		}
+	}
+	if(reqfirst)
+	{
+		req = reqfirst;
+		req->Detach();
+	}
+	LeaveMutex();
+	return req;
+}
+
 const char *TrunkGroup::getSchedule(char *buf)
 {
 	const char *scr = getLast("script");	// check for .conf override
@@ -802,6 +855,16 @@ const char *TrunkGroup::getSchedule(char *buf)
 	return buf;
 }
 
+const char *TrunkGroup::getNumber(void)
+{
+	const char *num = getLast("number");
+
+	if(num)
+		return num;
+
+	return "UNKNOWN";
+}
+
 void TrunkGroup::setSchedule(const char *str)
 {
 	if(!str)
@@ -927,6 +990,19 @@ phTone *getphTone(const char *name)
 		tone = tone->next;
 	}
 	return tone;
+}
+
+TrunkGroup *getGroup(const char *name)
+{
+	TrunkGroup *group = TrunkGroup::first;
+
+	while(group)
+	{
+		if(!stricmp(name, group->getName()))
+			return group;
+		group = group->next;
+	}
+	return NULL;
 }		
 
 KeyServer keyserver;
