@@ -83,7 +83,7 @@ bool Fifo::submit(char **argv)
 }
 
 
-bool Fifo::ringScript(int argc, char **argv)
+bool Fifo::ringScript(char **argv)
 {
 	Trunk *trunk = getTrunk(argv[1]);
 	TrunkEvent event;
@@ -97,7 +97,32 @@ bool Fifo::ringScript(int argc, char **argv)
 	return trunk->postEvent(&event);
 }
 
-bool Fifo::startScript(int argc, char **argv)
+bool Fifo::reqScript(char **argv)
+{
+	int argc = 4;
+	char buffer[512];
+	strstream str(buffer, sizeof(buffer));
+	TrunkGroup *grp;
+	char *exp = argv[1];
+	
+	if(!exp || !argv[2])
+		return false;
+
+	grp = getGroup(argv[2]);
+	if(!grp || !argv[3])
+		return false;
+
+	buffer[0] = 0;
+	str << argv[3];
+	while(argv[argc])
+		str << " " << argv[argc++];
+
+	str << ends;
+	new Request(grp, buffer, atoi(exp));
+	return true;
+}
+
+bool Fifo::startScript(char **argv)
 {
 	Trunk *trunk = getTrunk(argv[1]);	
 	TrunkEvent event;
@@ -163,6 +188,27 @@ bool Fifo::idleLine(char **argv)
 	event.id = TRUNK_MAKE_IDLE;
 	return trunk->postEvent(&event);
 }
+
+bool Fifo::mapFiles(char **argv)
+{
+	int count = 0;
+	char pathname[128];
+
+	while(*(++argv))
+	{
+		strcpy(pathname, "maps/");
+		strcat(pathname, *argv);
+		strcat(pathname, ".map");
+		if(!canAccess(pathname))
+			continue;
+		new Map(pathname, *argv);
+		++count;
+	}
+	if(count)
+		return true;
+	else
+		return false;
+}
 		
 bool Fifo::Command(const char *cmd)
 {
@@ -254,15 +300,19 @@ bool Fifo::Command(const char *cmd)
 	else if(!stricmp(argv[0], "debug"))
 		rts = debug->DebugFifo(argv);
 	else if(!stricmp(argv[0], "ring"))
-		rts = ringScript(argc, argv);
+		rts = ringScript(argv);
 	else if(!stricmp(argv[0], "busy"))
 		rts = busyLine(argv);
 	else if(!stricmp(argv[0], "idle"))
 		rts = idleLine(argv);
 	else if(!stricmp(argv[0], "start"))
-		rts = startScript(argc, argv);	
+		rts = startScript(argv);	
+	else if(!stricmp(argv[0], "request"))
+		rts = reqScript(argv);
 	else if(!stricmp(argv[0], "disconnect") || !stricmp(argv[0], "hangup"))
 		rts = hangupLine(argv);
+	else if(!stricmp(argv[0], "map"))
+		rts = mapFiles(argv);
 	LeaveMutex();
 	return rts;
 }
