@@ -35,6 +35,46 @@ bool Trunk::scrRecord(void)
 	return false;
 }
 
+bool Trunk::scrMap(void)
+{
+	char *map = getValue(NULL);
+	char *key = getValue(NULL);
+	char *prefix;
+	char **list, **tok;
+	unsigned len;
+
+	if(!key)
+	{
+		Error("no-key-value");
+		return true;
+	}
+
+	while(NULL != (prefix = getValue(NULL)))
+	{
+		len = strlen(prefix);
+		if(!strncmp(prefix, key, len))
+		{
+			key += len;
+			break;
+		}
+	}
+	
+	list = getMap(map, key);
+	if(!list)
+	{
+		Advance();
+		return true;
+	}
+
+	if(!Redirect(*list))
+	{
+		Error("map-script-missing");
+		return true;
+	}
+	setList(++list);
+	return true;
+}
+
 bool Trunk::scrAppend(void)
 {
 	data.record.name = getValue("");	
@@ -388,6 +428,48 @@ bool Trunk::scrLibonce(void)
 	return true;
 }
 
+bool Trunk::scrRequest(void)
+{
+	TrunkGroup *grp;
+	char buffer[512];
+	strstream str(buffer, sizeof(buffer));
+	char *arg;
+	unsigned expires = atoi(getValue("0"));
+	
+	buffer[0] = 0;
+	arg = getValue(NULL);
+	if(!arg)
+	{
+		Error("request-no-group");
+		return true;
+	}
+	grp = getGroup(arg);
+	if(!grp)
+	{
+		Error("request-unknown-group");
+		return true;
+	}
+	arg = getValue(NULL);
+	if(!arg)
+	{
+		Error("request-no-script");
+		return true;
+	}
+	str << arg;
+
+	while(NULL != (arg = getOption(NULL)))
+	{
+		if(*arg != '%')
+			continue;
+
+		str << " " << (arg + 1) << "=" << getContent(arg);
+	}
+	str << ends;
+	new Request(grp, buffer, expires);
+	Advance();
+	return true;
+}	
+
 bool Trunk::scrLibexec(void)
 {
 	tgicmd_t cmd;
@@ -423,26 +505,13 @@ bool Trunk::scrLibexec(void)
 	
 	str << " digits=" << dtmf.bin.data;		
 
-	qc = getSymbol("ani");
+	qc = getSymbol(SYM_CALLER);
 	if(qc)
-		str << " ani=" << qc;
+		str << " clid=" << qc;
 
-	qc = getSymbol("dnis");
+	qc = getSymbol(SYM_DIALED);
 	if(qc)
-		str << " dnis=" << qc;
-
-	qc = getSymbol("did");
-	if(qc)
-		str << " did=" << qc;
-
-	qc = getSymbol("callerid");
-	if(qc)
-	{
-		str << " cid=" << qc;
-		qc = getSymbol("callername");
-		if(qc)
-			str << keyserver.getToken() << qc;
-	}
+		str << " dnid=" << qc;
 
 	if(!data.sleep.wakeup)
 		cmd.detach = true;
