@@ -176,30 +176,18 @@ static void tgi(void)
 				continue;
 			}
 
-			if(!strnicmp(argv[argc], "cid=", 4))
+			if(!strnicmp(argv[argc], "dlid=", 5))
 			{
-				setenv("PORT_CID", argv[argc] + 4, 1);
+				setenv("PORT_DLID", argv[argc] + 5, 1);
 				continue;
 			}
 
-			if(!strnicmp(argv[argc], "ani=", 4))
+			if(!strnicmp(argv[argc], "clid=", 5))
 			{
-				setenv("PORT_ANI", argv[argc] + 4, 1);
+				setenv("PORT_CLID", argv[argc] + 5, 1);
 				continue;
 			}
 
-			if(!strnicmp(argv[argc], "did=", 4))
-			{
-				setenv("PORT_DID", argv[argc] + 4, 1);
-				continue;
-			}
-
-			if(!strnicmp(argv[argc], "dnis=", 5))
-			{
-				setenv("PORT_DNIS", argv[argc] + 5, 1);
-				continue;
-			}
-		
 			if(!strnicmp(argv[argc], "query=", 6))
 			{
 				setenv("PORT_QUERY", argv[argc] + 6, 1);
@@ -244,6 +232,7 @@ static RETSIGTYPE final(int sig)
 	network.Stop();
 	scheduler.Stop();
 	stopServers();
+	endMaps();
 
 	if(resolver)
 		delete resolver;
@@ -398,6 +387,8 @@ static void initial(int argc, char **argv)
 	mkdir("tmp", 0770);
 	mkdir("prompts", 0770);
 	mkdir("cache", 0700);
+	mkdir("maps", 0700);
+
 	if(!getuid())
 	{
 		chown(keypaths.getDatafiles(), keyserver.getUid(), keyserver.getGid());
@@ -501,6 +492,14 @@ static void initial(int argc, char **argv)
 	}
 
 	keyserver.loadGroups();
+	if(canAccess("/etc/bayonne.clid"))
+		new Map("/etc/bayonne.clid", "clid");
+
+	if(canAccess("/etc/bayonne.dnis"))
+		new Map("/etc/bayonne.dnis", "dnis");
+
+	plugins.loadMaps();
+
 	sync();
 	ports = driver->Start();
 	if(ports)
